@@ -43,6 +43,7 @@
 #'   See the "Target objects" section for background.
 #' @inheritSection tar_map Target objects
 #' @inheritSection tar_rep Replicate-specific seeds
+#' @inheritSection tar_render Literate programming limitations
 #' @inheritSection tar_quarto Quarto troubleshooting
 #' @inheritParams tar_rep
 #' @inheritParams quarto::quarto_render
@@ -510,7 +511,7 @@ tar_quarto_rep_rep <- function(
   args$execute_params[["output_file"]] <- NULL
   args$execute_params[["tar_group"]] <- NULL
   seed <- as.integer(if_any(anyNA(seeds), NA_integer_, seeds[rep]))
-  if_any(anyNA(seed), NULL, tar_seed_set(seed = seed))
+  if_any(anyNA(seed), NULL, targets::tar_seed_set(seed = seed))
   result <- do.call(quarto::quarto_render, args)
   file.rename(temporary_file, destination_file)
   sort(as.character(fs::path_rel(unlist(destination_file))))
